from .grammar.master import Master
from .elements import CommandContext
import sys as _sys

if not hasattr(_sys, "_called_from_test"):
    # Some discussion here of whether this pattern is a good idea, I think it's fine for now.
    # https://stackoverflow.com/questions/9561042/python-init-py-and-initialization-of-objects-in-a-code
    Breathe = Master()
else:
    from dragonfly import get_engine
    engine = get_engine("text")
    Breathe = Master(engine=engine)



from setuptools import setup
import os

def read(*names):
    return open(os.path.join(os.path.dirname(__file__), *names)).read()

setup(
    name="dfly-breathe",
    version="0.1",
    description="Dragonfly command API",
    author="Mike Roberts",
    author_email="mike.roberts.2k10@googlemail.com",
    license="LICENSE.txt",
    url="https://github.com/mrob95/Breathe",
    long_description = read("README.md"),
    long_description_content_type='text/markdown',
    packages=["breathe"],
    install_requires=["dragonfly2"],
)

